==================================
Published Literature Using Mahotas
==================================

If you are using mahotas in a paper, please cite the `mahotas paper
<http://dx.doi.org/10.5334/jors.ac>`__ and I will list it here.

Here is a list of papers I found using mahotas in reverse chronological order
(newest first; the oldest predate the mahotas paper and were found with
google):

#.  Irina Gladkova, Yury Kihai, Alexander Ignatov, Fazlul Shahriar, and Boris
    Petrenko. *Exploring pattern recognition enhancements to ACSPO clear-sky
    mask for VIIRS: potential and limitations* Proc. SPIE 9111, Ocean Sensing
    and Monitoring VI, 91110G (May 23, 2014); `doi:10.1117/12.2053474
    <http://doi.org/10.1117/12.2053474>`__
#.  Carl-Magnus Svensson, Solveigh Krusekopf, Jörg Lücke and Marc Thilo Figge.
    *Automated detection of circulating tumor cells with naive Bayesian
    classifiers* Cytometry Part A Volume 85, Issue 6, pages 501–511, June 2014
    `doi:10.1002/cyto.a.22471 <http://doi.org/10.1002/cyto.a.22471>`__
#.  Adrian Fisher. *Cloud and Cloud-Shadow Detection in SPOT5 HRG Imagery with
    Automated Morphological Feature Extraction* Remote Sens. 2014, 6(1),
    776-800; `doi:10.3390/rs6010776 <http://doi.org/10.3390/rs6010776>`__
#.  Luis Pedro Coelho, Joshua D. Kangas, Armaghan W. Naik, Elvira Osuna-Highley,
    Estelle Glory-Afshar, Margaret Fuhrman, Ramanuja Simha, Peter B. Berget,
    Jonathan W. Jarvik, and Robert F. Murphy *Determining the subcellular
    location of new proteins from microscope images using local features*
    Bioinformatics (2013) 29 (18): 2343-2349 `doi:10.1093/bioinformatics/btt392
    <http://doi.org/10.1093/bioinformatics/btt392>`__
#.  Macáhlek, Tomas, and Kamila Olsevicova. *Decentralized Multi-Agent
    Algorithm for Translational 2D Image Alignment.* Multimedia and Internet
    Systems: Theory and Practice. Springer Berlin Heidelberg, 2013. 15-24.
    `doi:10.1007/978-3-642-32335-5_2 <http://10.1007/978-3-642-32335-5_2>`__
#.  Ploshnik, Elina, et al. *Hierarchical Structuring in Block Copolymer
    Nanocomposites through Two Phase Separation Processes Operating on
    Different Time Scales.* Advanced Functional Materials (2013).
    `doi:10.1002/adfm.201300091 <http://doi.org/10.1002/adfm.201300091>`__
#.  Mashburn, David N., et al. "Enabling user guided segmentation and
    tracking of surface labeled cells in time-lapse image sets of living
    tissues." Cytometry Part A 81.5 (2012): 409-418.o
    `doi:10.1002/cyto.a.22034 <http://doi.org/10.1002/cyto.a.22034>`__
#.  Dosiek, Luke, and Patrick D. Schalk. "Passive radiation detection using
    optically active CMOS sensors." SPIE Defense, Security, and Sensing.
    International Society for Optics and Photonics, 2013.
    `doi:10.1117/12.2015543 <http://doi.org/10.1117/12.2015543>`__

Let me know if I missed something.


